@@ -5,6 +5,7 @@
 from __future__ import absolute_import
 
 from flask import Flask
+from os.path import join, sep
 
 from ..project import current_project
 
@@ -12,21 +13,22 @@ pj = current_project
 conf = pj.config['PROJECT']
 
 app = Flask(
-  conf['APP_FOLDER'],
+  conf['APP_FOLDER'].replace(sep, '.'),
   static_folder=conf['APP_STATIC_FOLDER'],
   template_folder=conf['APP_TEMPLATE_FOLDER'],
-  instance_path=pj.root_dir,
-  instance_relative_config=True
+  instance_path=join(pj.root_dir, conf['APP_FOLDER']),
+  instance_relative_config=True,
 )
 app.config.update(pj.config['APP'])
 
 @app.context_processor
 def inject():
-  def static_url(request):
-    return conf['STATIC_URL'] or request.url_root + conf['APP_STATIC_FOLDER']
   return {
     'project_name': conf['NAME'],
-    'static_url': static_url,
   }
 
+@app.teardown_request
+def teardown_request_handler(exception=None):
+  pj._dismantle_database_connections()
+
 pj.app = app
